haskell-debugger
Safe HaskellNone
LanguageGHC2021

GHC.Debugger.Breakpoint.Map

Description

Meant to be qualified with import qualified GHC.Debugger.Breakpoint.Map as BM

Synopsis

Documentation

data BreakpointMap a Source #

A map keyed by InternalBreakpointId

Instances

Instances details
Outputable a => Outputable (BreakpointMap a) Source # 
Instance details

Defined in GHC.Debugger.Breakpoint.Map

Methods

ppr :: BreakpointMap a -> SDoc #

DebugView (BreakpointMap a) Source # 
Instance details

Defined in GHC.Debugger.Breakpoint.Map

Methods

debugValue :: BreakpointMap a -> VarValue

debugFields :: BreakpointMap a -> Program VarFields

lookupModuleIBIs :: Module -> BreakpointMap a -> [InternalBreakpointId] Source #

Retrieves all InternalBreakpointIds for a given Module Note: The internal breakpoints of a module are not necessarily the same as the source-level breakpoints, so this shouldn't be used to get all internal breakpoints with source-level occurrences in the given module.