haskell-debugger
Safe HaskellNone
LanguageGHC2021

GHC.Debugger.Debuggee

Contents

Synopsis

Documentation

mkExternalInterpreterSubProcessSetup :: StdStream -> StdStream -> StdStream -> (CreatedProcess -> IO ()) -> LogAction IO DebuggerLog -> DynFlags -> Ghc a -> Ghc a Source #

Takes std_in, std_out, std_err fields for createProcess and a callback for the result.

extInterpFromListeningSocket :: Socket -> IO Interp Source #

Make an ExtInterpInstance based on an external interpreter process running as 'hdb external-interpreter --port $port'.

The process is expected to connect to '$port' and send its own PID as the first line on the socket before the GHCi wire protocol begins.

The given Socket should be listening on '$port'.

Note: no attempt is made to capture the standard inputoutputerror.

Logging

data DebuggerLog Source #

A debugger log. May include debuggee ouput.