haskell-debugger
Safe HaskellNone
LanguageGHC2021

GHC.Debugger.Runtime

Synopsis

Documentation

obtainTerm :: TermKey -> Debugger Term Source #

Obtain the runtime Term from a TermKey.

The TermKey will be looked up in the TermCache to avoid recomputing the Term if possible. On a cache miss the Term will be reconstructed from scratch and stored in the cache.

expandTerm :: HscEnv -> Term -> IO Term Source #

Before returning a Term we want to expand its heap representation up to the defaultDepth

For Ids, this is done by obtainTermFromId. For other TermKeys this function should be used