haskell-debugger
Safe HaskellNone
LanguageGHC2021

GHC.Debugger.Runtime.Eval.RemoteExpr.Builtin

Description

A module providing various remote external variables which are available by default in any session.

A good way to check whether some function or variable can be added here is if you can successfully ask for the type of its fully qualified name on ghci (e.g. :t Data.List.singleton)

Meant to be imported qualified as Remote: import GHC.Debugger.Runtime.Eval.RemoteExpr (RemoteExpr) import qualified GHC.Debugger.Runtime.Eval.RemoteExpr as Remote import qualified GHC.Debugger.Runtime.Eval.RemoteExpr.Builtin as Remote

Synopsis

Documentation

pair :: RemoteExpr (a -> b -> (a, b)) Source #

fst :: RemoteExpr ((a, b) -> a) Source #

snd :: RemoteExpr ((a, b) -> b) Source #

decodeStackWithIpe :: RemoteExpr StackSnapshot -> RemoteExpr (IO [(StackFrame, Maybe InfoProv)]) Source #

Remote 'GHC.Internal.Stack.Decode.decodeStackWithIpe"

compose :: RemoteExpr (b -> c) -> RemoteExpr (a -> b) -> RemoteExpr (a -> c) Source #

Function composition on the remote process