| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
GHC.Debugger.Runtime.Instances
Synopsis
- debugValueTerm :: Term -> Debugger (Maybe VarValueResult)
- debugFieldsTerm :: Term -> Debugger (Maybe [(String, Term)])
- data VarValueResult = VarValueResult {}
Documentation
debugValueTerm :: Term -> Debugger (Maybe VarValueResult) Source #
Get the custom representation of this Term by applying a DebugView
instance debugValue method if there is one.
debugFieldsTerm :: Term -> Debugger (Maybe [(String, Term)]) Source #
Get the custom representation of this Term by applying a DebugView
instance debugFields method if there is one.
Returns the mappings from field labels to terms, where each term records the type and pointer to the foreign heap value returned in the instance for that label.
Returns Nothing if no instance was found for the type of the given term
data VarValueResult Source #
Constructors
| VarValueResult | |
Fields | |