haskell-debugger
Safe HaskellNone
LanguageGHC2021

GHC.Debugger.Runtime.Internal

Description

A module providing various remote external variables which we want available in any session. It gets compiled in-memory at the start of one.

See Note [debuggerInternal unit].

Synopsis

Documentation

cons :: a -> [a] -> [a] Source #

See nil.

nil :: [a] Source #

Some extensions can mess with [] and (:) syntax, so we setup these plain function aliases.

noPrintConstant :: a -> IO () Source #

We setInteractivePrintName with this so REPL results are forced but not already printed to debug console.

evalWrapper :: String -> [String] -> IO a -> IO a #

concat :: Foldable t => t [a] -> [a] #

The concatenation of all the elements of a container of lists.

Examples

Expand

Basic usage:

>>> concat (Just [1, 2, 3])
[1,2,3]
>>> concat (Left 42)
[]
>>> concat [[1, 2, 3], [4, 5], [6], []]
[1,2,3,4,5,6]

putStrLn :: String -> IO () #

The same as putStr, but adds a newline character.

This operation may fail with the same errors, and has the same issues with concurrency, as hPutStr!