haskell-debugger
Safe HaskellNone
LanguageGHC2021

GHC.Debugger.Runtime.Thread

Contents

Description

TODO - [] Consider caching once and forall the expressions we dynamically compile and load in this module.

Synopsis

Documentation

listAllLiveRemoteThreads :: Debugger [(RemoteThreadId, ThreadInfo ForeignRef)] Source #

Call listThreads on the (possibly) remote debuggee process to get the list of threads running on the debuggee. Filter by running threads This may include the debugger threads if using the internal interpreter.

Re-exports

data ThreadInfo (ref :: Type -> Type) Source #

Instances

Instances details
Generic (ThreadInfo ref) Source # 
Instance details

Defined in GHC.Debugger.Runtime.Interpreter.Types

Associated Types

type Rep (ThreadInfo ref) 
Instance details

Defined in GHC.Debugger.Runtime.Interpreter.Types

type Rep (ThreadInfo ref) = D1 ('MetaData "ThreadInfo" "GHC.Debugger.Runtime.Interpreter.Types" "haskell-debugger-0.13.2.0-inplace" 'False) (C1 ('MetaCons "ThreadInfo" 'PrefixI 'True) (S1 ('MetaSel ('Just "threadInfoRef") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (ref ThreadId)) :*: (S1 ('MetaSel ('Just "threadInfoLabel") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe String)) :*: S1 ('MetaSel ('Just "threadInfoStatus") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 ThreadStatus))))

Methods

from :: ThreadInfo ref -> Rep (ThreadInfo ref) x #

to :: Rep (ThreadInfo ref) x -> ThreadInfo ref #

type Rep (ThreadInfo ref) Source # 
Instance details

Defined in GHC.Debugger.Runtime.Interpreter.Types

type Rep (ThreadInfo ref) = D1 ('MetaData "ThreadInfo" "GHC.Debugger.Runtime.Interpreter.Types" "haskell-debugger-0.13.2.0-inplace" 'False) (C1 ('MetaCons "ThreadInfo" 'PrefixI 'True) (S1 ('MetaSel ('Just "threadInfoRef") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (ref ThreadId)) :*: (S1 ('MetaSel ('Just "threadInfoLabel") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe String)) :*: S1 ('MetaSel ('Just "threadInfoStatus") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 ThreadStatus))))