haskell-debugger
Safe HaskellNone
LanguageGHC2021

GHC.Debugger.Runtime.Thread.Map

Contents

Description

A map to track and manage the debuggee runtime threads

Synopsis

Documentation

type ThreadMap = IntMap (ForeignRef ThreadId) Source #

A thread map maintains a mapping between the int thread identifier, which uniquely identifies a thread spawned by the debuggee, and the (possibly remote) reference to the thread (i.e. the corresponding ThreadId)

emptyThreadMap :: ThreadMap Source #

It's empty, what did you expect?

Operations

insertThreadMap :: Int -> ForeignRef ThreadId -> ThreadMap -> ThreadMap Source #

Insert a remote ThreadId at this unique Int thread identifier

lookupThreadMap :: Int -> ThreadMap -> Maybe (ForeignRef ThreadId) Source #

Lookup a remote ThreadId by its unique Int identifier

threadMapToList :: ThreadMap -> [(Int, ForeignRef ThreadId)] Source #

Get all the remote thread references from the ThreadMap