haskell-debugger
Safe HaskellNone
LanguageGHC2021

GHC.Debugger.Stopped.Exception

Description

Helpers used when the debugger is stopped due to an exception. These helpers execute code on the remote process which teach us information about the exception we are stopped at.

Synopsis

Documentation

getExceptionInfo :: RemoteThreadId -> Debugger ExceptionInfo Source #

Retrieve structured exception information for the requested thread when the debugger is currently stopped on an exception.

defaultExceptionInfo :: ExceptionInfo Source #

Placeholder exception info returned when the context could not be inspected.