haskell-debugger
Safe HaskellNone
LanguageGHC2021

GHC.Debugger.Stopped.Variables

Synopsis

Documentation

tyThingToVarInfo :: FamInstEnvs -> TyThing -> Debugger VarInfo Source #

TyThing to VarInfo. The Bool argument indicates whether to force the value of the thing (as in True = :force, False = :print)

termVarFields :: FamInstEnvs -> TermKey -> Term -> Debugger VarFields Source #

Construct the VarInfos of the fields (VarFields) of the given TermKey/Term

This is used to come up with terms for the fields of an already seqed variable which was expanded.

termToVarInfo :: FamInstEnvs -> TermKey -> Term -> Debugger VarInfo Source #

Construct a VarInfo from the given Name of the variable and the Term it binds The FamInstEnvs is used to look through newtypes and type families when checking if suspensions are of function type.

getFamInstEnvs' :: Debugger FamInstEnvs Source #

Thin wrapper around tcGetFamInstEnvs, using runTcInteractive

forceTerm :: Term -> Debugger Term Source #

Forces a term to WHNF

The term is updated in the cache at the given key.