| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
GHC.Debugger.Debuggee
Contents
Synopsis
- data InterpreterSettings = InterpreterSettings {
- interpreterFlags :: DynFlags -> DynFlags
- interpreterSetup :: forall a. LogAction IO DebuggerLog -> DynFlags -> Ghc a -> Ghc a
- mkExternalInterpreterFlags :: String -> DynFlags -> DynFlags
- mkInternalInterpreterFlags :: DynFlags -> DynFlags
- mkInternalInterpreterSetup :: LogAction IO DebuggerLog -> DynFlags -> Ghc a -> Ghc a
- newtype InconsistentInterpreterFlags = InconsistentInterpreterFlags String
- mkExternalInterpreterFromIOSetup :: IO Interp -> LogAction IO DebuggerLog -> DynFlags -> Ghc a -> Ghc a
- type CreatedProcess = (Maybe Handle, Maybe Handle, Maybe Handle, ProcessHandle)
- mkExternalInterpreterSubProcessSetup :: StdStream -> StdStream -> StdStream -> (CreatedProcess -> IO ()) -> LogAction IO DebuggerLog -> DynFlags -> Ghc a -> Ghc a
- extInterpFromListeningSocket :: Socket -> IO Interp
- mkCliInterpreterSettings :: Bool -> Maybe FilePath -> IO InterpreterSettings
- data DebuggerLog
- data DebuggerMessage
- ghcLogAction :: LogAction IO DebuggerLog -> LogAction
- msgClassSeverity :: MessageClass -> Severity
Documentation
data InterpreterSettings Source #
Constructors
| InterpreterSettings | |
Fields
| |
mkInternalInterpreterSetup :: LogAction IO DebuggerLog -> DynFlags -> Ghc a -> Ghc a Source #
newtype InconsistentInterpreterFlags Source #
Constructors
| InconsistentInterpreterFlags String |
Instances
| Exception InconsistentInterpreterFlags Source # | |
| Show InconsistentInterpreterFlags Source # | |
Defined in GHC.Debugger.Debuggee Methods showsPrec :: Int -> InconsistentInterpreterFlags -> ShowS # show :: InconsistentInterpreterFlags -> String # showList :: [InconsistentInterpreterFlags] -> ShowS # | |
mkExternalInterpreterFromIOSetup :: IO Interp -> LogAction IO DebuggerLog -> DynFlags -> Ghc a -> Ghc a Source #
type CreatedProcess = (Maybe Handle, Maybe Handle, Maybe Handle, ProcessHandle) Source #
mkExternalInterpreterSubProcessSetup :: StdStream -> StdStream -> StdStream -> (CreatedProcess -> IO ()) -> LogAction IO DebuggerLog -> DynFlags -> Ghc a -> Ghc a Source #
Takes std_in, std_out, std_err fields for createProcess and a callback for the result.
extInterpFromListeningSocket :: Socket -> IO Interp Source #
Make an ExtInterpInstance based on an external interpreter process
running as 'hdb external-interpreter --port $port'.
The process is expected to connect to '$port' and send its own PID as the first line on the socket before the GHCi wire protocol begins.
The given Socket should be listening on '$port'.
Note: no attempt is made to capture the standard inputoutputerror.
Logging
data DebuggerLog Source #
A debugger log. May include debuggee ouput.
Constructors
| DebuggerLog !Severity !DebuggerMessage | |
| GHCLog !LogFlags !MessageClass !SrcSpan !SDoc | |
| DebuggerSessionLog !Severity !Text |
data DebuggerMessage Source #
A debugger log message
Constructors
| LogSDoc !DynFlags !SDoc | |
| LogFailedToCompileBuiltinModule !ModuleName | |
| LogSkippingViewModuleNoPkg !ModuleName String [String] |
Instances
| Show DebuggerMessage Source # | |
Defined in GHC.Debugger.Debuggee Methods showsPrec :: Int -> DebuggerMessage -> ShowS # show :: DebuggerMessage -> String # showList :: [DebuggerMessage] -> ShowS # | |