| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
GHC.Debugger.Runtime.Eval.RemoteExpr.Builtin
Description
A module providing various remote external variables which are available by default in any session.
A good way to check whether some function or variable can be added here is
if you can successfully ask for the type of its fully qualified name on ghci
(e.g. :t Data.List.singleton)
Meant to be imported qualified as Remote:
import GHC.Debugger.Runtime.Eval.RemoteExpr (RemoteExpr)
import qualified GHC.Debugger.Runtime.Eval.RemoteExpr as Remote
import qualified GHC.Debugger.Runtime.Eval.RemoteExpr.Builtin as Remote
Synopsis
- pair :: RemoteExpr (a -> b -> (a, b))
- fst :: RemoteExpr ((a, b) -> a)
- snd :: RemoteExpr ((a, b) -> b)
- cloneThreadStack :: RemoteExpr ThreadId -> RemoteExpr (IO StackSnapshot)
- decode :: RemoteExpr StackSnapshot -> RemoteExpr (IO [StackEntry])
- decodeStack :: RemoteExpr StackSnapshot -> RemoteExpr (IO StgStackClosure)
- ssc_stack :: RemoteExpr StgStackClosure -> RemoteExpr [StackFrame]
- decodeStackWithIpe :: RemoteExpr StackSnapshot -> RemoteExpr (IO [(StackFrame, Maybe InfoProv)])
- getClosureData :: RemoteExpr StgStackClosure -> RemoteExpr (IO Closure)
- fromThreadId :: RemoteExpr ThreadId -> RemoteExpr Word64
- threadStatus :: RemoteExpr ThreadId -> RemoteExpr (IO ThreadStatus)
- listThreads :: RemoteExpr (IO [ThreadId])
- threadLabel :: RemoteExpr ThreadId -> RemoteExpr (IO (Maybe String))
- peekCString :: RemoteExpr CString -> RemoteExpr (IO String)
- indexAddrArray :: RemoteExpr ByteArray# -> RemoteExpr (Int# -> Ptr a)
- maybeToList :: RemoteExpr (Maybe a) -> RemoteExpr [a]
- compose :: RemoteExpr (b -> c) -> RemoteExpr (a -> b) -> RemoteExpr (a -> c)
- displayStackAnnotation :: RemoteExpr SomeStackAnnotation -> RemoteExpr String
- displayStackAnnotationShort :: RemoteExpr SomeStackAnnotation -> RemoteExpr String
- stackAnnotationSourceLocation :: RemoteExpr SomeStackAnnotation -> RemoteExpr (Maybe SrcLoc)
- unpackStackFields :: RemoteExpr ([StackField] -> Maybe [Int] -> IO [HValue])
Documentation
pair :: RemoteExpr (a -> b -> (a, b)) Source #
fst :: RemoteExpr ((a, b) -> a) Source #
snd :: RemoteExpr ((a, b) -> b) Source #
cloneThreadStack :: RemoteExpr ThreadId -> RemoteExpr (IO StackSnapshot) Source #
Remote cloneThreadStack
decode :: RemoteExpr StackSnapshot -> RemoteExpr (IO [StackEntry]) Source #
Remote decode
decodeStack :: RemoteExpr StackSnapshot -> RemoteExpr (IO StgStackClosure) Source #
Remote decodeStack
ssc_stack :: RemoteExpr StgStackClosure -> RemoteExpr [StackFrame] Source #
Remote ssc_stack
decodeStackWithIpe :: RemoteExpr StackSnapshot -> RemoteExpr (IO [(StackFrame, Maybe InfoProv)]) Source #
Remote 'GHC.Internal.Stack.Decode.decodeStackWithIpe"
getClosureData :: RemoteExpr StgStackClosure -> RemoteExpr (IO Closure) Source #
Remote getClosureData
fromThreadId :: RemoteExpr ThreadId -> RemoteExpr Word64 Source #
Remote fromThreadId
threadStatus :: RemoteExpr ThreadId -> RemoteExpr (IO ThreadStatus) Source #
Remote threadStatus
listThreads :: RemoteExpr (IO [ThreadId]) Source #
Remote listThreads
threadLabel :: RemoteExpr ThreadId -> RemoteExpr (IO (Maybe String)) Source #
Remote threadLabel
peekCString :: RemoteExpr CString -> RemoteExpr (IO String) Source #
Remote peekCString
indexAddrArray :: RemoteExpr ByteArray# -> RemoteExpr (Int# -> Ptr a) Source #
Remote indexAddrArray#
maybeToList :: RemoteExpr (Maybe a) -> RemoteExpr [a] Source #
Remote maybeToList
compose :: RemoteExpr (b -> c) -> RemoteExpr (a -> b) -> RemoteExpr (a -> c) Source #
Function composition on the remote process
stackAnnotationSourceLocation :: RemoteExpr SomeStackAnnotation -> RemoteExpr (Maybe SrcLoc) Source #
unpackStackFields :: RemoteExpr ([StackField] -> Maybe [Int] -> IO [HValue]) Source #