| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
GHC.Debugger.Runtime.Thread
Contents
Description
TODO - [] Consider caching once and forall the expressions we dynamically compile and load in this module.
Synopsis
- getRemoteThreadIdFromRemoteContext :: ForeignRef (ResumeContext [HValueRef]) -> Debugger RemoteThreadId
- getRemoteThreadId :: ForeignRef ThreadId -> Debugger RemoteThreadId
- listAllLiveRemoteThreads :: Debugger [(RemoteThreadId, ThreadInfo ForeignRef)]
- data ThreadInfo (ref :: Type -> Type) = ThreadInfo {
- threadInfoRef :: !(ref ThreadId)
- threadInfoLabel :: !(Maybe String)
- threadInfoStatus :: !ThreadStatus
Documentation
getRemoteThreadIdFromRemoteContext :: ForeignRef (ResumeContext [HValueRef]) -> Debugger RemoteThreadId Source #
Get a RemoteThreadId from a remote ResumeContext gotten from an ExecBreak
listAllLiveRemoteThreads :: Debugger [(RemoteThreadId, ThreadInfo ForeignRef)] Source #
Call listThreads on the (possibly) remote debuggee process to get the
list of threads running on the debuggee. Filter by running threads
This may include the debugger threads if using the internal interpreter.
Re-exports
data ThreadInfo (ref :: Type -> Type) Source #
Constructors
| ThreadInfo | |
Fields
| |