| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
GHC.Debugger.Session.Builtin
Contents
Description
Built-in units and modules
Synopsis
- debuggerViewBuiltinMods :: [(ModuleName, StringBuffer)]
- debuggerViewInstancesMods :: [(ModuleName, StringBuffer, String)]
- debuggerViewClassModName :: ModuleName
- debuggerViewClassContents :: StringBuffer
- hsDebuggerViewInMemoryUnitId :: UnitId
- addInMemoryHsDebuggerViewUnit :: GhcMonad m => [UnitId] -> DynFlags -> m ()
- makeInMemoryTarget :: UnitId -> ModuleName -> StringBuffer -> IO Target
- runInternal :: GhcMonad m => m a -> m a
- debuggerInternalUnitId :: UnitId
- addInMemoryDebuggerInternalUnit :: (MonadFail m, GhcMonad m) => DynFlags -> m ()
- debuggerRuntimeInternalContents :: StringBuffer
- debuggerRuntimeInternalModName :: ModuleName
- debuggerRuntimeInternalUnit :: Unit
- debuggerRuntimeInternalModule :: Module
- addInMemoryFFIInspectUnit :: GhcMonad m => [UnitId] -> DynFlags -> m UnitId
- hsDebuggerFFIInspectUnitId :: UnitId
- debuggerRuntimeFFIInspectModName :: ModuleName
- debuggerRuntimeFFIInspectContents :: StringBuffer
Built-in mods
debuggerViewBuiltinMods :: [(ModuleName, StringBuffer)] Source #
The set of modules to load from haskell-debugger-view.
NOTE: This list should always be kept up to date with the modules listed in
exposed-modules in haskell-debugger-view to make sure all (possibly
orphan) instances are loaded and available.
debuggerViewInstancesMods :: [(ModuleName, StringBuffer, String)] Source #
The modules which provide orphan instances for types defined in external packages. We will try to load each of these modules separately.
debuggerViewClassModName :: ModuleName Source #
GHC.Debugger.View.Class
debuggerViewClassContents :: StringBuffer Source #
The contents of GHC.Debugger.View.Class in memory
In memory unit
hsDebuggerViewInMemoryUnitId :: UnitId Source #
The fixed unit-id (haskell-debugger-view-in-memory) for when we load the haskell-debugger-view modules in memory
addInMemoryHsDebuggerViewUnit Source #
Arguments
| :: GhcMonad m | |
| => [UnitId] | The unit-ids from the transitive dependencies closure of the user-given targets |
| -> DynFlags | Dynflags resulting from first downsweep of user given targets |
| -> m () |
Create a unit haskell-debugger-view which uses in-memory files for the modules
and add it to the HUG
makeInMemoryTarget :: UnitId -> ModuleName -> StringBuffer -> IO Target Source #
Make an in-memory Target for a module from the module name and contents
runInternal :: GhcMonad m => m a -> m a Source #
debuggerRuntimeInternalContents :: StringBuffer Source #
The contents of GHC.Debugger.Runtime.FFIInspect in memory
hsDebuggerFFIInspectUnitId :: UnitId Source #
The fixed unit-id (haskell-debugger-ffi-inspect) used to load GHC.Debugger.Runtime.FFIInspect in the debuggee when we can't have custom ghci-serv commands.
debuggerRuntimeFFIInspectContents :: StringBuffer Source #
The contents of GHC.Debugger.Runtime.FFIInspect in memory